@@ -22,15 +22,12 @@ try:
     from cymysql.charsetx import charset_by_name, charset_by_id
 except ImportError:
     from cymysql.charset import charset_by_name, charset_by_id
-try:
-    from cymysql.cursorsx import Cursor
-except ImportError:
-    from cymysql.cursors import Cursor
+from cymysql.cursors import Cursor
 from cymysql.constants.CLIENT import *
 from cymysql.constants.COMMAND import *
 try:
     from cymysql.convertersx import escape_item, encoders, decoders
-except:
+except ImportError:
     from cymysql.converters import escape_item, encoders, decoders
 from cymysql.err import raise_mysql_exception, Warning, Error, \
      InterfaceError, DataError, DatabaseError, OperationalError, \
@@ -294,7 +291,6 @@ class Connection(object):
         self.decoders = conv
 
         self._result = None
-        self._affected_rows = 0
         self.host_info = "Not connected"
 
         self.autocommit(False)
@@ -383,15 +379,16 @@ class Connection(object):
         if DEBUG:
             print("sending query: %s" % sql)
         self._execute_command(COM_QUERY, sql)
-        self._affected_rows = self._read_query_result()
-        return self._affected_rows
+        self._result = self._read_query_result()
 
     def next_result(self):
-        self._affected_rows = self._read_query_result()
-        return self._affected_rows
+        self._result = self._read_query_result()
 
     def affected_rows(self):
-        return self._affected_rows
+        if self._result:
+            self._result._affected_rows
+        else:
+            return 0
 
     def kill(self, thread_id):
         arg = struct.pack('<I', thread_id)
@@ -465,8 +462,7 @@ class Connection(object):
     def _read_query_result(self):
         result = MySQLResult(self)
         result.read()
-        self._result = result
-        return result.affected_rows
+        return result
 
     def insert_id(self):
         if self._result:
