@@ -288,47 +288,41 @@ class MySQLResult(object):
         self.message = None
         self.field_count = 0
         self.description = None
-        self.rows = None
         self.has_next = None
+        self.has_result = False
+        self.rest_rows = None
 
     def read(self):
+        self.rest_rows = None
         self.first_packet = self.connection.read_packet()
 
-        # TODO: use classes for different packet types?
         if self.first_packet.is_ok_packet():
-            self._read_ok_packet()
+            (self.affected_rows, self.insert_id,
+                self.server_status, self.warning_count,
+                self.message) = self.first_packet.read_ok_packet()
+            self.has_result = False
         else:
-            self._read_result_packet()
+            self.field_count = ord(self.first_packet.read(1))
+            self._get_descriptions()
+            self.has_result = True
 
-    def _read_ok_packet(self):
-        (self.affected_rows, self.insert_id,
-            self.server_status, self.warning_count,
-            self.message) = self.first_packet.read_ok_packet()
-
-    def _read_result_packet(self):
-        self.field_count = ord(self.first_packet.read(1))
-        self._get_descriptions()
-        self._read_rowdata_packet()
-
-    # TODO: implement this as an iteratable so that it is more
-    #       memory efficient and lower-latency to client...
-    def _read_rowdata_packet(self):
-      """Read a rowdata packet for each data row in the result set."""
-      rows = []
-      decoders = self.connection.decoders
-      while True:
-        packet = self.connection.read_packet()
-        if packet.is_eof_packet():
-            self.warning_count = unpack_uint16(packet.read(2))
-            server_status = unpack_uint16(packet.read(2))
-            self.has_next = (server_status
+    def read_rest_rowdata_packet(self):
+        """Read rest rowdata packets for each data row in the result set."""
+        if (not self.has_result) or (self.rest_rows is not None):
+            return
+        rest_rows = []
+        decoders = self.connection.decoders
+        while True:
+            packet = self.connection.read_packet()
+            if packet.is_eof_packet():
+                self.warning_count = unpack_uint16(packet.read(2))
+                server_status = unpack_uint16(packet.read(2))
+                self.has_next = (server_status
                              & SERVER_STATUS.SERVER_MORE_RESULTS_EXISTS)
-            break
-        rows.append(tuple([packet.read_decode_data(decoders, self.fields[i])
-                                            for i in range(len(self.fields))]))
-
-      self.affected_rows = len(rows)
-      self.rows = rows
+                break
+            rest_rows.append(tuple([packet.read_decode_data(decoders,
+                            self.fields[i]) for i in range(len(self.fields))]))
+        self.rest_rows = rest_rows
 
     def _get_descriptions(self):
         """Read a column descriptor packet for each column in the result."""
@@ -342,3 +336,22 @@ class MySQLResult(object):
         eof_packet = self.connection.read_packet()
         assert eof_packet.is_eof_packet(), 'Protocol error, expecting EOF'
         self.description = tuple(description)
+
+    def fetchone(self):
+        if not self.has_result:
+            return None
+        if self.rest_rows is None:
+            decoders = self.connection.decoders
+            packet = self.connection.read_packet()
+            if packet.is_eof_packet():
+                self.warning_count = unpack_uint16(packet.read(2))
+                server_status = unpack_uint16(packet.read(2))
+                self.has_next = (server_status
+                             & SERVER_STATUS.SERVER_MORE_RESULTS_EXISTS)
+                self.rest_rows = []
+                return None
+            return tuple([packet.read_decode_data(decoders, self.fields[i])
+                                            for i in range(len(self.fields))])
+        elif len(self.rest_rows):
+            return self.rest_rows.pop(0)
+        return None
